import * as React from 'react';
import { FieldErrors, FieldValues, UseFormGetValues, UseFormRegister, UseFormReset, UseFormSetError, UseFormWatch } from 'react-hook-form';
import { ARTICLESLIST_LAYOUT_TYPE, ARTICLES_SCOPE, ARTICLE_HEADER_TITLE_ALIGNMENT, ARTICLE_HEADER_TITLE_LOCATION, ARTICLE_HEADLINE, ARTICLE_TYPE, ARTICLE_VIEW_TYPES, BLOCK, DEVIDER_BREADCRUMB, FEATURED_MOBILE, FIXTURE_RESULT_LAYOUT, FIXTURE_RESULT_SIZE, Fixture_Status, FLEX_ALIGNMENTS, GRID_DIMENSIONS, HOMEICON_BREADCRUMB, HOMETYPE_BREADCRUMB, LAYOUT_TYPE, RESOURCE, SIZE, SIZES_OPTIONS, SMALL_FEATURED_NUM, TAB_STYLES, THUMBNAILS_SIZE, VISIBILITY } from './enums';
export interface IHeaderProps {
    logoUrl?: string;
    brand?: string;
    hasSocialIcons?: boolean;
    routesList: Array<Route>;
    user?: IUser | undefined;
    socialLinks?: {
        [key: string]: string;
    };
    mobileRoutesList?: Array<Route>;
    isAuthenticated?: boolean;
    onAuthClick?: () => void;
    notifications: {
        notifications: INotification[];
        settingsRoute: string;
        reloadNotifications: any;
        handleReadAllNotifications: () => void;
        handleReadNotificationById?: (id: any) => void;
        paginate: () => void;
        newNotificationsCount: number;
        clearNewNotifications: () => void;
        labels: {
            title: string;
            readAll: string;
            readMore: string;
            settings: string;
        };
    };
    search: {
        submit: any;
        register: any;
        placeholder?: string;
    };
    darkMode?: {
        isDarkMode: boolean;
        toggleDarkMode: () => void;
    };
}
export type TEmbedContentProps = {
    service: string;
    source: string;
    embed: string;
    width: number;
    height: number;
    caption: string;
};
export interface IUser {
    id: number;
    name: string;
    username: string;
    email: string;
    provider: string | null;
    provider_id: string | null;
    fb_user_access_token?: null;
    image: string;
    status: string;
    custom_data: {
        test: string;
        android_telefoon: string;
    };
    date_of_birth: string;
    settings: {
        night_mode: boolean;
        notifications?: boolean;
        notify_by_likes: boolean;
        notify_by_replies: boolean;
        notify_by_likes_on_email?: boolean;
        notify_by_replies_on_email?: boolean;
    };
    last_login: string;
    created_at?: string;
    updated_at?: string;
    is_public: boolean;
    enable_notifications_popup: boolean;
    claps_count: number;
    profile_image: string;
    origin_profile_image: string;
}
export type Route = {
    id: number;
    name: string;
    resource_type?: string;
    resource_id?: number | null;
    order?: number;
    destination?: string;
    url: string;
    children?: Array<Route> | [];
};
export type THomePageContext = {
    data: {
        bigArticles?: TArticle[] | [];
        smallArticles?: TArticle[] | [];
        hideSmallArticlesOnMobile?: boolean;
    };
};
export type TArticleDetailsPageContext = {
    article: IArticle | undefined;
};
export interface TFeaturedArticlesListProps {
    data: {
        bigArticles?: TArticle[];
        smallArticles?: TArticle[];
        hideSmallArticlesOnMobile?: boolean;
    };
    showCounts: boolean;
    showDate: boolean;
    showTag: boolean;
}
export type TFeaturedArticlesListContaier = {
    Component: React.FC<TFeaturedArticlesListProps>;
    options: {
        showCounts: boolean;
        showDate: boolean;
        showTag: boolean;
    };
};
export type TArticleDetailsContainer = {
    Component: React.FC<TArticleDetailsProps>;
};
export type TArticleDetailsProps = {
    article: IArticle;
};
export type TSummeryArticlesListProps = {
    options: any;
    data: UseArticlesListData;
};
export type TSummeryArticlesListContainer = {
    Component: React.FC<TSummeryArticlesListProps>;
    options: any;
    hookConfig: any;
    data: UseArticlesListData;
};
export type UseArticlesListData = {
    title: string;
    articles: IArticle[];
    groupedArticles?: {
        [key: string]: IArticle[];
    };
    group: string;
    loading: boolean;
    hasPagination?: boolean;
    paginationLabel?: string;
    paginate?: (e?: any) => void;
    handleEmitAbTestResult?: (e?: any) => void;
};
export type TBreadCrumbProps = {
    basePath?: string;
    pathes: Array<Route>;
};
export type TBreadCrumbContainer = {
    Component: React.FC<TBreadCrumbProps>;
};
export type TArticlesListProps = {
    data: UseArticlesListData;
};
export type TArticlesListContaier = {
    hookConfig: any;
    Component: React.FC<TArticlesListProps & TArticleListOptions & {
        loader: any;
    }>;
    options: TArticleListOptions;
};
export type TArticle = {
    id: number;
    slug: string;
    title: string;
    a_title: string;
    b_title: string;
    abtesting: boolean;
    excerpt: string;
    author: IAuthor;
    published_at: string;
    updated_at: string;
    disable_ads: boolean;
    image: string;
    primary_tag: ITag;
    tags: ITag[];
    comments_count: number;
    claps_count: number;
    claps_users_count: number;
    views: number;
    content: {
        time: number;
        blocks: TBlock[];
        version: string;
    };
    related_articles: IRelatedArticle[];
    related_polls: IArticlePoll[];
    related_items: number[];
    content_images: IContentImage[];
    url: string;
    meta_title: string;
    meta_description: string;
    thumbnails: IThumbnails;
    thumbnails_without_watermark: IThumbnails;
    rrsLink?: string;
    type: ARTICLE_TYPE;
    in_headline: ARTICLE_HEADLINE;
    enable_comments: boolean;
    is_bold: boolean;
    source: string;
    source_url: string;
};
export type TClapsButtonProps = {
    usersCount: number;
    clapsCount: number;
    clapResource: () => void;
};
export interface ICommentFormData {
    content: string;
}
export interface IUseCommentFormHookData extends IFormControllerProps<ICommentFormData> {
    isReply?: boolean;
    isUpdate?: boolean;
    labels: {
        label: string;
        placeholder: string;
        cancle: string;
        submit: {
            update: string;
            reply: string;
            comment: string;
        };
    };
}
export interface IUseCommentListenerHookProps {
    resourceId: number;
    resourceType: RESOURCE;
    setCommentsCount: React.Dispatch<React.SetStateAction<number>>;
    handleLoadComments: (offest?: number) => void;
}
export interface IUseCommentFormHookProps {
    isReply?: boolean;
    isUpdate?: boolean;
    defaultComment?: string;
    hideCommentBox?: (e?: any) => void;
    handleCommentAction: (comment: string) => void;
}
export type NewCommentNotification = {
    resource_id: number;
    resource_type: RESOURCE;
    user_id: number;
};
export interface IUseCommentHookProps {
    level?: number;
    parentId?: number;
    comment: Comment;
    setCommentsCount: React.Dispatch<React.SetStateAction<number>>;
    comments: Comment[];
    setComments: React.Dispatch<React.SetStateAction<Comment[]>>;
    resourceType: RESOURCE;
    resourceId: number;
}
export interface IUseCommentListenerHookData {
    newCommentsCount: number;
    handReleLoadComments: (e: React.MouseEvent<HTMLButtonElement>) => void;
}
export type TInteractiveCommentsContainer = {
    Component: React.FC<IUseCommentsHookData & {
        t?: any;
    }>;
    options: {
        resourceType?: RESOURCE;
    };
};
export interface ITag {
    id: number;
    comments_count?: number;
    enable_comments?: boolean;
    title: string;
    meta_title: string;
    url: string;
    slug: string;
    claps_users_count: number;
    claps_count: number;
    content?: {
        time: number;
        blocks: BlockType[];
        version: string;
    };
    collection_id?: number;
}
export type TBlock = ParagraphType | HeadingType | TableType | ListType | EmbedType | CollectionItemType | RelatedArticlesType | EditorLiveBlogType | EditorImageType;
export interface IRelatedArticle {
    id: number;
    title: string;
    slug: string;
    url: string;
    image: string;
    image_origin_url: string;
}
export interface IContentImage {
    id: number;
    url: string;
    numeration?: string;
    caption?: string;
    origin_url: string;
    watermark?: string;
}
export interface IArticlePoll {
    id: number;
    question: string;
    status: string;
    answers: {
        id: number;
        answer: string;
    }[];
}
export interface IRelatedArticle {
    id: number;
    title: string;
    slug: string;
    url: string;
    image: string;
    image_origin_url: string;
    published_at?: string;
}
export interface ISmartbar {
    text: string;
    button_text: string;
    link: string;
    visibility: VISIBILITY;
    links: string[];
    start_at: string;
    date: string;
    end_at: string;
}
export type ParamsType = {
    [slug: string]: any;
};
export type ParagraphType = {
    data: {
        map?: {
            [key: string]: string;
        };
        text: string;
    };
    type: BLOCK.Paragraph;
};
export type HeadingType = {
    data: {
        text: string;
        level: number;
    };
    type: BLOCK.Heading;
};
export type TableType = {
    data: {
        content: string[][];
    };
    type: BLOCK.Table;
};
export type ListType = {
    data: {
        items: string[];
        style: 'ordered' | 'unordered';
    };
    type: BLOCK.List;
};
export type EmbedType = {
    data: {
        embed: string;
        width: number;
        height: number;
        source: string;
        caption: string;
        service: 'youtube' | 'twitter' | 'instagram';
    };
    type: BLOCK.Embed;
};
export type PollType = {
    data: {
        poll_id: number;
    };
    type: BLOCK.Poll;
};
export type EditorLiveBlogType = {
    data: {
        text: string;
    };
    type: BLOCK.EditorLiveBlog;
};
export type EditorImageType = {
    data: {
        id: string;
        url: string;
        link: string;
        width: string;
        height: string;
        caption: string;
        numeration: string;
        link_new_page: boolean;
    };
    type: BLOCK.EditorImage;
};
export type EditorGallery = any;
export type RawType = {
    data: {
        html: string;
    };
    type: BLOCK.Raw;
};
export type QuoteType = {
    data: {
        text: string;
        caption: string;
        alignment: string;
    };
    type: BLOCK.Quote;
};
export type CollectionItemType = {
    data: {
        id: string;
    }[];
    type: BLOCK.CollectionItem;
};
export type RelatedArticlesType = {
    data: {
        id: string;
    }[];
    type: BLOCK.RelatedArticles;
};
type EditorGalleryType = any;
export type BlockType = ParagraphType | HeadingType | TableType | ListType | EmbedType | CollectionItemType | QuoteType | RelatedArticlesType | EditorLiveBlogType | EditorImageType | EditorGalleryType | RawType | PollType;
export interface IMenu {
    id: number;
    name: string;
    resource_type: RESOURCE;
    resource_id: number;
    order: number;
    destination: 'same' | 'new';
    url: string;
    children: IMenu[];
}
export interface IAds {
    id: number;
    name: string;
    slug: string;
    content: string;
    position: string;
}
export interface ISettings {
    language: string;
    smartbar: ISmartbar;
    popup: IPopup;
    'name_website.value': string;
    'sidebar_dynamic_news_list.title': string;
    'article_next-prev.value': boolean;
    'article_show_settings.show_author': boolean;
    'article_show_settings.show_updated_at': boolean;
    'article_show_settings.show_comment_option': boolean;
    'article_show_settings.allow_comments_on_tag': boolean;
    'article_show_settings.sidebar_total_articles': number;
    'article_show_settings.hide_headline_articles_from_lists': true;
    'article_create_settings.show_source_field': boolean;
    'article_create_settings.infinity_scroll'?: boolean;
    'external_rss.url': string;
    'external_rss.title': string;
    'external_rss.enable': boolean;
    'external_rss.number_of_articles': number;
    'external_rss.url_read_more': string;
    'second_external_rss.url': string;
    'second_external_rss.title': string;
    'second_external_rss.enable': boolean;
    'second_external_rss.number_of_articles': number;
    'second_external_rss.url_read_more': string;
    'recaptcha.token': string;
    'google.analytic_id': null;
    'meta.title': string;
    'meta.description': string;
    'facebook.page_url': string;
    'twitter.page_url': string;
    'instagram.page_url': string;
    is_facebook_login_available: true;
    is_google_login_available: true;
    'website_images.default_image': string;
    'website_images.origin_default_image': string;
    'website_images.logo': string;
    'website_images.origin_logo': string;
    'website_images.fav_icons': string;
    'website_images.origin_fav_icon': string;
    'website_images.dark_logo': string;
    'website_images.origin_dark_logo': string;
    'pwa.icon': string;
    'pwa.origin_icon': string;
    'pwa.splash': string;
    'pwa.origin_splash': string;
    domain: string;
    footer_text?: string;
}
export interface IThumbnails {
    origin: string | null;
    xsmall_300?: string | null;
    xsmall_400?: string | null;
    medium?: string | null;
    fullurl?: string | null;
    watermark?: string | null;
}
export interface IPopup {
    title: string;
    content: {
        blocks: BlockType[];
    };
    formattedContent: string;
    htmlContent: string;
    jsonContent: {
        images?: IContentImage[];
        articles?: IRelatedArticle[];
        polls?: IArticlePoll[];
    };
    buttonText: string;
    link: string;
    visibility: VISIBILITY;
    links: string[];
    logoId: number;
    logoPath: string;
    reducedLogoPath: string;
    lastUpdateAt: string;
}
export interface ILatestComments {
    url: string;
    user_url: string;
    claps_count: number;
    content: string;
    date: string;
    resource: string;
    user: string;
    user_avatar: string;
}
export interface IArticleComment {
    id: number;
    content: string;
    replies_count: number;
    likes_count: number;
    username: string;
    user_id: number;
    user_likes: number;
    user_avatar: string;
    user_avatar_origin: string;
    user_url: string;
    level: number;
    created_at: string;
    updated_at: string;
    can_like_it: boolean;
    can_report_it: boolean;
    can_edit: boolean;
    can_delete: boolean;
    show_as_dark: boolean;
    author_role: string;
    show_author_role: boolean;
    show_the_badge: boolean;
    replies: IArticleComment[];
}
export interface IUser {
    id: number;
    name: string;
    username: string;
    email: string;
    provider: string | null;
    provider_id: string | null;
    fb_user_access_token?: null;
    image: string;
    status: string;
    custom_data: {
        test: string;
        android_telefoon: string;
    };
    date_of_birth: string;
    settings: {
        night_mode: boolean;
        notifications?: boolean;
        notify_by_likes: boolean;
        notify_by_replies: boolean;
        notify_by_likes_on_email?: boolean;
        notify_by_replies_on_email?: boolean;
    };
    thumbnails: {
        xsmall_300: string;
        xsmall_400: string;
        medium: string;
        origin: string;
        fullurl: string;
    };
    last_login: string;
    created_at?: string;
    updated_at?: string;
    is_public: boolean;
    enable_notifications_popup: boolean;
    claps_count: number;
    profile_image: string;
    origin_profile_image: string;
}
export interface IAuthor {
    id: number;
    is_public: boolean;
    name: string;
    username: string;
    author_url: string;
    avatar: string | null;
    articles?: IArticle[];
    avatar_origin_url: string | null;
    links?: {
        twitter: string;
    };
    description?: string;
}
export interface ITag {
    id: number;
    title: string;
    meta_title: string;
    url: string;
    slug: string;
    claps_users_count: number;
    claps_count: number;
}
export interface IArticle {
    id: number;
    slug: string;
    title: string;
    a_title: string | null;
    b_title: string | null;
    abtesting: boolean | null | undefined;
    excerpt: string;
    bold_title?: number;
    author: IAuthor;
    published_at: string;
    updated_at: string;
    disable_ads: boolean;
    image: string;
    primary_tag: ITag;
    tags: ITag[];
    comments_count: number;
    claps_count: number;
    claps_users_count: number;
    views: number;
    content?: {
        time: number;
        blocks: BlockType[];
        version: string;
    };
    related_articles?: IRelatedArticle[];
    related_polls?: IArticlePoll[];
    related_items?: number[];
    content_images?: IContentImage[];
    url: string;
    meta_title: string;
    meta_description: string | null;
    thumbnails: IThumbnails;
    thumbnails_without_watermark: IThumbnails;
    rrsLink?: string;
    type: ARTICLE_TYPE;
    in_headline?: ARTICLE_HEADLINE;
    enable_comments: boolean;
    is_sticky?: boolean;
    is_bold: boolean;
    watermark?: string;
    source: string | null;
    source_url: string | null;
}
export type RouteItem = {
    label: string;
    path?: string;
    isActive: boolean;
    children?: RouteItem[];
};
export type NotificationsHookData = {
    notifications: INotification[];
    settingsRoute: string;
    newNotificationsCount: number;
    clearNewNotifications: () => void;
    handleReadNotificationById?: (id: any) => void;
    handleReadAllNotifications: () => void;
    paginate: () => void;
    reloadNotifications: () => void;
    labels: {
        title: string;
        readAll: string;
        readMore: string;
        settings: string;
    };
};
export type Article = {
    id: number;
    slug: string;
    title: string;
    a_title: string;
    b_title: string;
    abtesting: boolean;
    excerpt: string;
    author: IAuthor;
    published_at: string;
    updated_at: string;
    disable_ads: boolean;
    image: string;
    primary_tag: ITag;
    tags: ITag[];
    comments_count: number;
    claps_count: number;
    claps_users_count: number;
    views: number;
    content: {
        time: number;
        blocks: BlockType[];
        version: string;
    };
    related_articles: IRelatedArticle[];
    related_polls: IArticlePoll[];
    related_items: number[];
    content_images: IContentImage[];
    url: string;
    meta_title: string;
    meta_description: string;
    thumbnails: IThumbnails;
    thumbnails_without_watermark: IThumbnails;
    rrsLink?: string;
    type: ARTICLE_TYPE;
    in_headline: ARTICLE_HEADLINE;
    enable_comments: boolean;
    is_bold: boolean;
    source: string;
    source_url: string;
};
export type Comment = {
    id: number;
    content: string;
    replies_count: number;
    likes_count: number;
    username: string;
    user_id: number;
    user_likes: number;
    user_avatar: string;
    replay_to: number;
    user_avatar_origin: string;
    user_url: string;
    level: number;
    created_at: string;
    updated_at: string;
    can_like_it: boolean;
    can_report_it: boolean;
    can_edit: boolean;
    can_delete: boolean;
    show_as_dark: boolean;
    author_role: string;
    show_author_role: boolean;
    show_the_badge: boolean;
    replies: Array<Comment>;
};
export type CommentSummary = {
    url: string;
    user_url: string;
    claps_count: number;
    replies_count: number;
    content: string;
    date: string;
    resource: string;
    user: string;
    user_avatar: string;
};
export type PublicUserComment = {
    id: number;
    content: string;
    date: string;
    date_and_time: string;
    replies_count: number;
    likes_count: number;
    username: 'string';
    user_id: number;
    user_likes: number;
    user_avatar: null;
    user_avatar_origin: null;
    user_url: 'string';
    level: number;
    replies: [];
    can_like_it: boolean;
    status: string;
    created_at: string;
    updated_at: string;
    flagged: number;
    show_as_dark: boolean;
    author_role: string;
    show_author_role: boolean;
    show_the_badge: boolean;
    can_edit: boolean;
    can_delete: boolean;
    url: string;
};
export type PublicUser = {
    id: number;
    name: string;
    username: string;
    avatar: string;
    avatar_origin_url: string;
    public_url: string;
    author_url: string;
    status: 'active' | 'new';
    custom_data: any;
    links: {
        twitter: string;
    };
    created_at: string;
    comments_count: number;
    claps_count: number;
};
export type LatestComment = {
    url: string;
    user_url: string;
    claps_count: number;
    content: string;
    date: string;
    resource: string;
    user: string;
    user_avatar: string;
};
export interface ILoginProps extends IFormControllerProps<TLoginFormData> {
    showForgotPassword?: () => void;
    showRegister?: () => void;
    socialLogin?: ISocialLoginProps;
    labels?: {
        title?: string;
        hint?: string;
        username?: string;
        usernamePlaceholder?: string;
        password?: string;
        passwordPlaceholder?: string;
        registerBtn?: string;
        login?: string;
    };
}
export interface ISocialLoginProps {
    hasFacebookLogin?: boolean;
    loginWithFacebook: () => void;
    hasGoogleLogin?: boolean;
    loginWithGoogle: () => void;
}
export type TLoginFormData = {
    login: string;
    password: string;
};
export interface IModalProps {
    show: boolean;
    size: SIZE;
    onClose: (e?: any) => void;
    onOpen?: (e?: any) => void;
    backgroundColor?: string;
    children?: React.ReactNode;
}
export interface IUserChangePasswordFormData {
    current_password: string;
    password: string;
    password_confirmation: string;
}
export interface INotification {
    id: string;
    read_at: string;
    open_at: string;
    created_at: string;
    url: string;
    type: string;
    resource_title: string;
    resource_type: string;
    user_name: string;
    text: string;
    comment: string;
    user_url: string;
    resource_id: number;
    comment_id: number;
    user_avatar: string;
}
export interface ICollectionItem {
    id: number;
    title: string;
    claps_count: number;
    enable_comments: boolean;
    claps_users_count: number;
    meta_title: string;
    meta_description: string;
    comments_count: number;
    slug: string;
    content: {
        time: number;
        blocks: BlockType[];
        version: string;
    };
    fields: IFieldBlock[] | ISimpleFieldBlock[];
    collection_id: number;
    collection: ICollection;
    views: number;
    is_category: boolean;
    is_visible: boolean;
}
export interface ICollection {
    id: number;
    name: string;
    slug: string;
    meta_title: string;
    meta_description: string;
    views: number;
    content: {
        time: number;
        blocks: BlockType[];
        version: string;
    };
    created_at: string;
    comments_count: number;
    updated_at: string;
    is_filterable: boolean;
}
export interface IFieldBlock {
    field: {
        id: number;
        type: string;
        label: string;
    };
    value: {
        id: number;
        tag_id: number;
        value: any;
    };
}
export interface ISimpleFieldBlock {
    id: number;
    label: string;
    type: string;
    value: any;
}
export type DefaultArticlesListProps<T> = T & {
    data: {
        title: string;
        articles: IArticle[];
        hasPagination?: boolean;
        loading?: boolean;
        paginate?: () => void;
        group?: string;
        paginationLabel?: string;
        handleEmitAbTestResult?: (e?: unknown) => void;
    };
};
export type IArticleCardProps<T> = T & {
    data: IArticle;
    handleEmitAbTestResult?: (e?: any) => void;
    loader: any;
    group?: string;
};
export type TVerticleListOptionsProps = {
    showBorder?: boolean;
    showCounts?: boolean;
    showDateOf?: boolean;
    highlightFirstItem?: boolean;
    imageSize?: THUMBNAILS_SIZE;
    padding?: SIZES_OPTIONS;
    readMoreLink?: string;
    gap?: SIZES_OPTIONS;
    imageRounded?: SIZES_OPTIONS;
    rounded?: SIZES_OPTIONS;
    titleSize?: SIZES_OPTIONS;
    showDateGroup?: boolean;
    headerBackground?: boolean;
    showImage?: boolean;
    hideOnMobile?: boolean;
    showArrow?: boolean;
    hasPagination: true;
};
export type TSearchWidgetOptions = {
    title?: string;
    searchIcon?: boolean;
    allowSearchInContent?: boolean;
    showButton?: boolean;
    buttonRounded?: SIZES_OPTIONS;
    inputIsInline?: boolean;
};
export type TSearchWidgetData = {
    t: any;
    LinkComponent: any;
    searchState: TSearchState;
    handleChangeInputText: (e: React.ChangeEvent<HTMLInputElement>) => void;
    handleToggleContent: (e: React.ChangeEvent<HTMLInputElement>) => void;
    handleSubmitSearch: (e: React.FormEvent<HTMLFormElement>) => void;
};
export type TSearchState = {
    inputText: string;
    content: boolean;
};
export type THorizontalListOptionsProps = {
    showCounts?: boolean;
    showDateOf?: boolean;
    headerBackground?: boolean;
    showDescription?: boolean;
    rounded?: SIZES_OPTIONS;
    title?: string;
    countsOutside?: boolean;
    group?: string;
    showTag?: boolean;
    sliderOnMobile?: boolean;
    showDateGroup?: boolean;
    showAuthor?: boolean;
    tagOutside?: boolean;
};
export type TSummaryListOptionsProps = {
    showCounts?: boolean;
    title?: string;
};
export type TDetailedListOptions = {
    showCounts?: boolean;
    showDateOf?: boolean;
    highlightFirstItem?: boolean;
    padding?: SIZES_OPTIONS;
    headerBackground?: boolean;
    imageSize?: THUMBNAILS_SIZE;
    readMoreLink?: string;
    rounded?: SIZES_OPTIONS;
    showDescription?: boolean;
    showAuthor?: boolean;
    showTag?: boolean;
    imageRounded?: SIZES_OPTIONS;
    showDateGroup?: boolean;
};
export type TArticleListOptions = {
    seeAllRoute?: Route | any;
    showBorder?: boolean;
    likeIcon?: 'thumbsup' | 'heart' | 'claps';
    showCounts?: boolean;
    showDateOf?: boolean;
    padding?: SIZES_OPTIONS;
    title?: string;
    authorBy?: boolean;
    sliderOnMobile?: boolean;
    authorIsPremium?: boolean;
    showArticleTitle?: boolean;
    smallImage?: boolean;
    showAuthorIcon?: boolean;
    gap?: SIZES_OPTIONS;
    showBackgroundTitle?: boolean;
    readMoreLink?: string;
    showColoredLine?: boolean;
    showAuthor?: boolean;
    tagOutside?: boolean;
    hasPagination?: boolean;
    rounded?: SIZES_OPTIONS;
    tagOutline?: boolean;
    showImage?: boolean;
    showDate?: boolean;
    showDiscription?: boolean;
    showTopLeftIcon?: boolean;
    countsOutside?: boolean;
    showDateGroup?: boolean;
    showDateWithCounts?: boolean;
    hideOnMobile?: boolean;
    buttonRounded?: SIZES_OPTIONS;
    cardRounded?: SIZES_OPTIONS;
    imageRounded?: SIZES_OPTIONS;
    tagRounded?: SIZES_OPTIONS;
    showArrow?: boolean;
    showTag?: boolean;
    titleSize?: SIZES_OPTIONS;
    articleView?: ARTICLE_VIEW_TYPES;
    layout?: ARTICLESLIST_LAYOUT_TYPE;
    smallerCard?: boolean;
    group?: string;
};
export type TFeaturedArticlesOptions = {
    showCounts?: boolean;
    showDateOf?: boolean;
    mobileLayoutStyle?: FEATURED_MOBILE;
    showTag?: boolean;
    numberOfSmallArticles?: SMALL_FEATURED_NUM;
    showAuthor?: boolean;
    showInfoOutside?: boolean;
    gap?: SIZES_OPTIONS;
    rounded?: SIZES_OPTIONS;
    showColoredLine?: boolean;
};
export interface IFeaturedArticlesListData {
    data: {
        bigArticles?: IArticle[];
        smallArticles?: IArticle[];
    };
}
export type TTabComponentOptions = {
    tabsTitle: {
        title?: string;
        icon?: string;
    }[];
    activeTabIndex?: number;
    styles?: TAB_STYLES;
};
export type TFooterOptions = {
    showSocialLinks?: boolean;
    showMenu?: boolean;
    showSiteMap?: boolean;
    backgroundColorOnLightMode?: string;
    backgroundColorOnDarkMode?: string;
    logoPosition?: FLEX_ALIGNMENTS;
    socialIconsPosition?: FLEX_ALIGNMENTS;
};
export type TCommentsComponentOptions = {
    resourceType: RESOURCE.Tag;
};
export type TInteractiveCommentsOptions = {
    moderatorIcon?: boolean;
    premiumIcon?: boolean;
    showAvatar?: boolean;
    avatarRounded?: SIZES_OPTIONS;
    inputRounded?: SIZES_OPTIONS;
    showActions?: boolean;
};
export interface ISummeryArticlesProps {
    data: {
        title: string;
        articles: IArticle[];
        groupedArticles: {
            [key: string]: IArticle[];
        };
        group: string;
        loading: boolean;
        hasPagination?: boolean;
        paginationLabel?: string;
        paginate?: (e?: any) => void;
        handleEmitAbTestResult?: (e?: any) => void;
        seeAllRoute?: Route;
    };
    options?: {
        showCounts: boolean;
        showDate: boolean;
        articleView: ARTICLE_VIEW_TYPES;
        allowHorivontalScroll: boolean;
        showArrow?: boolean;
        title?: string | undefined;
    };
}
export type TFlexComponentOptions = {
    childrensDimension: GRID_DIMENSIONS;
    gap?: SIZES_OPTIONS;
};
export type BreadCrumbProps = {
    basePath: string;
    pathes: Array<Route>;
};
export type TBreadCrumbOptions = {
    deviderIcon?: DEVIDER_BREADCRUMB;
    homeIcon?: HOMEICON_BREADCRUMB;
    homeType?: HOMETYPE_BREADCRUMB;
    homeText?: string;
    logo?: string;
};
export type TArticleAuthor = {
    AuthorTitle?: boolean;
    photo?: boolean;
    showDate?: boolean;
};
export type TFeaturedCommentOptions = {
    title?: string;
    userPoints?: boolean;
    likesCount?: boolean;
    avatarRounded?: SIZES_OPTIONS;
};
export interface IComponentRegistry {
    uuid: string;
    id: string;
    options?: THeaderOptions | TSocialShare | ISeparatorOptions | TArticleAuthor | TVerticleListOptionsProps | THorizontalListOptionsProps | TDetailedListOptions | TFeaturedArticlesOptions | TSearchWidgetOptions | TFeaturedCommentOptions | TTabComponentOptions | TArticleHeaderOptions | TCommentsComponentOptions | TFlexComponentOptions | TBreadCrumbOptions | TInteractiveCommentsOptions | TAdvertisComponentOptions | TFooterOptions;
    hookConfig?: any;
    page?: string[];
    variation?: string;
    children?: IComponentRegistry[];
}
export interface IBuildifireRegistryNew {
    version: string;
    components: IComponentRegistry[];
}
export type TSocialShare = {
    inCircle?: boolean;
    withText?: boolean;
    whatsapp?: boolean;
    linkedIn?: boolean;
    showShareTo?: boolean;
    facebook?: boolean;
    telegram?: boolean;
    twitter?: boolean;
    link?: boolean;
    mail?: boolean;
};
export type TArticleHeaderOptions = {
    showCategory?: boolean;
    showDate?: boolean;
    showComments?: boolean;
    showLikes?: boolean;
    showAuthor?: boolean;
    authorUndertitle?: boolean;
    showAuthorPhoto?: boolean;
    titleLocation?: ARTICLE_HEADER_TITLE_LOCATION;
    titleAlignment?: ARTICLE_HEADER_TITLE_ALIGNMENT;
};
export type TArticleHeaderData = {
    title: string;
    image: string;
    tagRedirectUrl?: string;
    tagTitle?: string;
    watermark?: string;
    date?: string;
    commentsCount?: number;
    likesCount?: number;
    authorData?: IAuthor;
};
export type TAdvertisComponentOptions = {
    adContent?: string;
    minHeight?: string;
};
export type THeaderOptions = {
    showSocialLinksTop?: boolean;
    showSocialLinksBottom?: boolean;
    showLinksTop?: boolean;
    showLinksBottom?: boolean;
    showDrawer?: boolean;
    showDarkMode?: boolean;
    showSearch?: boolean;
    showSearchBoxInline?: boolean;
    backgroundColorOnLightMode?: string;
    backgroundColorOnDarkMode?: string;
};
export interface ILayoutRegistry {
    layout: LAYOUT_TYPE;
}
export interface IBuildifireRegistry {
    version: string;
    layout: LAYOUT_TYPE;
    components: {
        [key: string]: IComponentRegistry[];
    };
}
export interface IParametersCheck {
    checked: boolean;
}
export interface IParametersCounter {
    max: number;
    min: number;
    step: number;
}
export interface IObject<T extends ObjectType> {
    type: T;
    parameters: ParameterMap[T];
}
type ParameterMap = {
    checked: IParametersCheck;
    counter: IParametersCounter;
};
export type ObjectType = keyof ParameterMap;
export interface IMetadataControllerProps {
    title?: string;
    description?: string;
    image?: string;
    url?: string;
    canonicalUrl?: string;
    ampUrl?: string;
    type?: string;
    author?: string;
    date?: string;
}
export interface IResourceActionProps {
    resource: IArticle | ITag | ICollectionItem;
    resourceType: RESOURCE;
}
export interface IUseShareResourceHookData {
    shareResourceUrl: string;
    shareResourceTitle: string;
    shareOnFacebook: () => void;
    shareOnLinkedIn: () => void;
    shareOnTwitter: () => void;
    shareOnWhatsapp: () => void;
    isCopied: boolean;
    copyLink: () => void;
}
export interface ILiveBlog {
    title: string;
    updated_at: string;
    id: number;
    is_pinned: number;
    content: BlockType[];
    content_images: IContentImage[];
}
export interface ILiveBlogData {
    liveblogs: ILiveBlog[];
    ads: IAds;
    blocks_count_to_place_ad: number;
}
export interface IPoll {
    poll_id: number;
    is_closed: boolean;
    my_answer: number;
    question: string;
    total_voting: number;
    answers: {
        id: number;
        answer: string;
        answer_voting: number;
    }[];
}
export type UseArticlesListProps = {
    scope?: ARTICLES_SCOPE;
    title?: string;
    paginationLabel?: string;
    tagId: number;
    size?: number;
    defaultOffset?: number;
    scopeValue?: string;
    limit?: number;
    hasPagination?: boolean;
    options: any;
    isSticky: boolean;
    openedArticleId?: string | null;
    initialPageSize: number;
    initialOffset: number;
    paginationPageSize: number;
    excludeVisibleHeadlines: boolean;
};
export interface IUseClapResourceHookProps {
    usersCount: number;
    clapsCount: number;
    clapResource: () => void;
}
export type UseRelatedArticlesData = {
    nextArticle: IArticle | null;
    prevArticle: IArticle | null;
};
export interface IUseCommentHookProps {
    level?: number;
    parentId?: number;
    comment: Comment;
    comments: Comment[];
    setCommentsCount: React.Dispatch<React.SetStateAction<number>>;
    setComments: React.Dispatch<React.SetStateAction<Comment[]>>;
    resourceType: RESOURCE;
    resourceId: number;
}
export interface IUseCommentHookData {
    level: number;
    comment: IComment;
    userLikes: number;
    hasUserLikedComment: boolean;
    commentLikes: number;
    hasUserReportedComment: boolean;
    showReplyModal: boolean;
    handleOpenReplyModal: (onOpen: boolean) => void;
    isUserComment: () => boolean;
    handleReplyComment: (comment: string) => void;
    handleLikeComment: () => void;
    handleUpdateComment: (comment: string) => void;
    handleDeleteComment: () => void;
    handleReportComment: () => void;
    labels: {
        reportCommentError: string;
        reportCommentSuccess: string;
        like: string;
    };
}
export interface IComment {
    id: number;
    content: string;
    replies_count: number;
    likes_count: number;
    username: string;
    user_id: number;
    user_likes: number;
    replay_to: number;
    user_avatar: string;
    user_avatar_origin: string;
    user_url: string;
    level: number;
    created_at: string;
    updated_at: string;
    can_like_it: boolean;
    can_report_it: boolean;
    can_edit: boolean;
    can_delete: boolean;
    show_as_dark: boolean;
    author_role: string;
    show_author_role: boolean;
    show_the_badge: boolean;
    replies: IComment[];
}
export interface IUseCommentFormHookProps {
    isReply?: boolean;
    isUpdate?: boolean;
    defaultComment?: string;
    hideCommentBox?: (e?: any) => void;
    handleCommentAction: (comment: string) => void;
}
export interface ICommentFormData {
    content: string;
}
export interface IUseCommentFormHookData extends IFormControllerProps<ICommentFormData> {
    isReply?: boolean;
    isUpdate?: boolean;
    labels: {
        label: string;
        placeholder: string;
        cancle: string;
        submit: {
            update: string;
            reply: string;
            comment: string;
        };
    };
}
export interface IUseCommentsHookData {
    enableComments: boolean;
    comments: Comment[];
    commentsCount: number;
    setCommentsCount: React.Dispatch<React.SetStateAction<number>>;
    resourceType: RESOURCE;
    resourceId: number;
    setComments: React.Dispatch<React.SetStateAction<Comment[]>> | ((e?: any) => void);
    commentsLoading: boolean;
    hasMoreComments: boolean;
    isSingleComment: boolean;
    handleLoadComments: (offest?: number) => void;
    handlePostComment: (comment: string) => void;
    useCommentForm: (props: IUseCommentFormHookProps | any) => IUseCommentFormHookData | any;
    useCommentListener: (props: IUseCommentListenerHookProps | any) => IUseCommentListenerHookData | any;
    useComment: (props: IUseCommentHookProps | any) => IUseCommentHookData | any;
    labels?: {
        comment?: string;
        comments?: string;
        showAllComments?: string;
        readMoreComments?: string;
    };
}
export interface IPublicUser {
    id: number;
    name: string;
    username: string;
    avatar: string;
    avatar_origin_url: string;
    public_url: string;
    author_url: string;
    status: 'active' | 'new';
    custom_data: any;
    links: {
        twitter: string;
    };
    created_at: string;
    comments_count: number;
    claps_count: number;
}
export interface IUsePublicUserCommentsHookProps {
    user: IPublicUser;
}
export interface IUsePublicUserCommentsHooksData {
    comments: PublicUserComment[];
    loading: boolean;
    paginate: (e?: any) => void;
}
export interface IFilterOption {
    id: number;
    value: string;
    count: number;
    checked?: boolean;
}
export interface ICollectionAction {
    id: number;
    label: string;
    render_as: string;
    meta_type: string | null;
    type: string;
    has_more_options: boolean;
    order: number;
    action_meta: any;
    options: IFilterOption[];
    direction?: 'asc' | 'desc';
    selected?: boolean;
    value?: string | number[] | string[];
}
export interface IResource {
    resource: any;
    key: RESOURCE;
    other: any;
}
export interface IFile {
    id: number;
    route: string;
    content: string;
    redirect_url: string;
}
export interface IPublicUserComment {
    id: number;
    content: string;
    date: string;
    date_and_time: string;
    replies_count: number;
    likes_count: number;
    username: 'string';
    user_id: number;
    user_likes: number;
    user_avatar: null;
    user_avatar_origin: null;
    user_url: 'string';
    level: number;
    replies: [];
    can_like_it: boolean;
    status: string;
    created_at: string;
    updated_at: string;
    flagged: number;
    show_as_dark: boolean;
    author_role: string;
    show_author_role: boolean;
    show_the_badge: boolean;
    can_edit: boolean;
    can_delete: boolean;
    url: string;
}
export interface IForum {
    id: number;
    title: string;
    last_comment_date: string;
    created_at: string;
    meta_title: string;
    meta_description: string;
    published_at: string;
    comments_count: number;
    claps_count: number;
    claps_users_count: number;
    url: string;
    author: IAuthor;
    content: {
        blocks: BlockType[];
    };
    slug: string;
    image_id: number;
    image: string;
    thumbnails: IThumbnails;
    thumbnails_with_watermark: IThumbnails;
    related_polls: IArticlePoll[];
    related_articles: IRelatedArticle[];
    related_images: IContentImage[];
    content_images: IContentImage[];
    related_items: number[];
    enable_comments?: boolean;
}
export interface IFormControllerProps<T extends FieldValues> {
    register: UseFormRegister<T>;
    submit: () => Promise<void>;
    errors?: FieldErrors<T>;
    setError?: UseFormSetError<T>;
    reset?: UseFormReset<T>;
    watch?: UseFormWatch<T>;
    getValues?: UseFormGetValues<T>;
    setValue?: UseFormSetError<T>;
}
export interface IPublicUserDataProps {
    settings: ISettings;
    mainMenu?: IMenu;
    user: IPublicUser;
}
export interface ICommonPageData {
    settings: ISettings;
    mainMenu?: IMenu;
    bigArticles?: IArticle[];
    smallArticles?: IArticle[];
    registry: IBuildifireRegistry;
    headAds: IAdvertisment[];
    footerAds: IAdvertisment[];
}
export interface IAuthorDataProps {
    settings: ISettings;
    mainMenu?: IMenu;
    author: IAuthor;
}
export type ArticleAsListElement = Omit<IArticle, 'content_images' | 'claps_users_count' | 'claps_count' | 'tags' | 'content' | 'related_articles' | 'views' | 'related_polls' | 'related_items' | 'source_url' | 'source' | 'disable_ads' | 'claps_count' | 'enable_comments' | 'in_headline' | 'type' | 'thumbnails_without_watermark' | 'meta_description' | 'meta_title' | 'updated_at'>;
export interface Player {
    firstName: string;
    lastName: string;
    birthday: string;
    nationality: string;
    height?: string;
    weight?: string;
    birthCountry?: string;
    birthPlace?: string;
    position: string;
    formationPosition?: string;
    imagePath: string;
    sportMonksId: number;
    number?: number;
    seasonStats?: PlayerSeasonStatsEntity[];
    team: Team;
    shortName: string;
    commonName: string;
    key: number;
    countryFlag: string;
    countryName: string;
    mom_score?: number;
}
export interface PlayerSeasonStatsEntity {
    team: string;
    league: string;
    season: string;
    appearances: number;
    substitutesIn: number;
    substitutesOut: number;
    goals: number;
    assists: number;
    interceptions: number;
    saves: number;
    yellowCards: number;
    redCards: number;
    yellowRedCards: number;
    minutesPlayed?: number;
    rating?: string;
    fouls?: number;
    duelsWon?: number;
    duelsTotal?: number;
    foulsDrawn?: number;
    shotOnTarget?: number;
    shotTotal?: number;
    passes?: number;
    penaltiesWon?: number;
    passesAccuracy?: number;
}
export interface Team {
    currentSeasonStat: CurrentSeasonStat;
    name: string;
    logoPath: string;
    squad: Player[];
    sportMonkId: number;
    league: null;
}
export interface CurrentSeasonStat {
    team_id: number;
    season_id: number;
    stage_id: number;
    win: StatValues;
    draw: StatValues;
    lost: StatValues;
    goals_for: StatValues;
    goals_against: StatValues;
    clean_sheet: StatValues;
    failed_to_score: StatValues;
    penalties: Penalties;
    scoring_minutes: Minute[];
    goals_conceded_minutes: Minute[];
    avg_goals_per_game_scored: StatValues;
    avg_goals_per_game_conceded: StatValues;
    avg_first_goal_scored: AvgFirstGoal;
    avg_first_goal_conceded: AvgFirstGoal;
    attacks: number;
    dangerous_attacks: number;
    avg_ball_possession_percentage: string;
    fouls: number;
    avg_fouls_per_game: string;
    offsides: number;
    redcards: number;
    yellowcards: number;
    shots_blocked: number;
    shots_off_target: number;
    avg_shots_off_target_per_game: string;
    shots_on_target: number;
    avg_shots_on_target_per_game: string;
    avg_corners: string;
    total_corners: number;
    btts: number;
    goal_line: GoalLine;
    avg_player_rating: number;
    avg_player_rating_per_match: number;
    tackles: number;
}
export interface StatValues {
    total: number;
    home: number;
    away: number;
}
export interface Penalties {
    awarded: number;
    scored: number;
    conceded: number;
}
export interface Minute {
    period: Period[];
}
export interface Period {
    minute: string;
    count: number;
    percentage: number;
}
export interface AvgFirstGoal {
    total: string;
    home: string;
    away: string;
}
export interface GoalLine {
    over: {
        [key: string]: Over;
    };
    under: {
        [key: string]: Over;
    };
}
export interface Over {
    home: number;
    away: number;
}
export interface IUseTeamHookData {
    team: Team;
    fixtures: Fixture[];
    ranking: ClubRanking[];
    favoriteTeam: string;
    favoriteLeague: string;
    labels: {
        viewDetails: string;
        hideDetails: string;
        matches: string;
        offensiveActions: string;
        defensiveActions: string;
        violationsAndCards: string;
        goals: string;
        assists: string;
        matchesPlayed: string;
        minutesPlayed: string;
        substituteIn: string;
        substituteOut: string;
        shots: string;
        onTarget: string;
        pass: string;
        accuracy: string;
        foulsDrawn: string;
        penaltiesDrawn: string;
        interceptions: string;
        duels: string;
        won: string;
        fouls: string;
        yellowCards: string;
        redCards: string;
        yellowRedCards: string;
        latestMatches: string;
        topPlayers: string;
        showAll: string;
    };
}
export type Fixture = {
    url: string;
    key: string;
    id: number;
    external_id: number;
    league: string;
    league_id: number;
    league_logo: string;
    season: string;
    homeTeam: string;
    venue?: any;
    homeTeamLogoPath: string;
    awayTeam: string;
    awayTeamLogoPath: string;
    status: Fixture_Status;
    score: string;
    halfTimeScore: string;
    homeTeamStat?: TeamStat;
    awayTeamStat?: TeamStat;
    homeTeamLineUp?: TeamLineup;
    awayTeamLineUp?: TeamLineup;
    events?: Event[];
    odds?: any;
    time: {
        status: string;
        starting_at: {
            date_time: string;
            date: string;
            time: string;
            timestamp: number;
            timezone: string;
        };
        minute: number;
        second?: any;
        added_time?: any;
        extra_minute?: any;
        injury_time?: any;
    };
    date: Date;
    date_formatted: string;
    date_hi: string;
    homeTeamId: number;
    awayTeamId: number;
    sportMonksId: number;
    timeStr: string;
    dateStr: string;
    translatedDate: string;
    hasStarted: boolean;
};
export type TeamLineup = {
    formation: string;
    players: Player[];
};
export type SeasonRanking = {
    league: string;
    season: string;
    rankingName: string;
    teamRankings: TeamRanking[];
};
export type TeamRanking = {
    team: string;
    teamLogo: string;
    ranking: number;
    matchesPlayed: number;
    wins: number;
    draws: number;
    losses: number;
    goalsScored: number;
    goalsConceded: number;
    points: number;
};
export type ClubRanking = {
    league: string;
    season: string;
    rankingName: string;
    teamRankings: TeamRanking[];
};
export interface TeamStat {
    possession: number;
    fouls: number;
    offsides: number;
    corners: number;
    shots: number;
    shotsOnTarget: number;
    yellowCards: number;
    yellowRedCards: number;
    redCards: number;
    goals: number;
    assists?: number;
}
export interface IUseRankingHookData {
    league: string;
    seasonRanking: SeasonRanking;
    favoriteTeam: string;
    labels: {
        showAll: string;
    };
}
export interface PlayerSeasonStatsEntity {
    team: string;
    league: string;
    season: string;
    appearances: number;
    substitutesIn: number;
    substitutesOut: number;
    goals: number;
    assists: number;
    interceptions: number;
    saves: number;
    yellowCards: number;
    redCards: number;
    yellowRedCards: number;
    minutesPlayed?: number;
    rating?: string;
    fouls?: number;
    duelsWon?: number;
    duelsTotal?: number;
    foulsDrawn?: number;
    shotOnTarget?: number;
    shotTotal?: number;
    passes?: number;
    penaltiesWon?: number;
    passesAccuracy?: number;
}
export interface IUsePlayerHookData {
    player: Player;
    displayDetailsButton?: boolean;
    labels: {
        viewDetails: string;
        hideDetails: string;
        matches: string;
        offensiveActions: string;
        defensiveActions: string;
        violationsAndCards: string;
        goals: string;
        assists: string;
        matchesPlayed: string;
        minutesPlayed: string;
        substituteIn: string;
        substituteOut: string;
        shots: string;
        onTarget: string;
        pass: string;
        accuracy: string;
        foulsDrawn: string;
        penaltiesDrawn: string;
        interceptions: string;
        duels: string;
        won: string;
        fouls: string;
        yellowCards: string;
        redCards: string;
        yellowRedCards: string;
    };
}
export interface MatchStatsProps {
    fixture: Fixture;
    labels: {
        title: string;
        teamStats: string;
        shots: string;
        ShotsOnTarget: string;
        Possession: string;
        Fouls: string;
        YellowCards: string;
        Offsides: string;
        Corners: string;
    };
}
export interface Event {
    type: string;
    team: string;
    player: Player;
    relatedPlayer: Player;
    minute: number;
    result: string;
}
export interface Vote {
    votes: number;
    player_id: number;
}
export interface IUseLeaguesHookData {
    leagues: League[];
    fixturesByLeague: Record<string, Fixture[]>;
    handleGetFixturesByDate: (date: string) => void;
    favoriteTeam: string;
    labels: {
        viewAllMatchesButton: string;
        viewResultsAndSchedule: string;
        showAll: string;
    };
}
export type League = {
    league: string;
    leagueId: number;
    leagueLogo: string;
    season: string;
    id: number;
    sportMonkId: number;
};
export interface ILeagueProps {
    league: League;
    fixturesByLeague: Record<string, Fixture[]>;
    day: Date;
    labels: {
        viewResultsAndSchedule: string;
        showAll: string;
    };
}
export interface IUseFixtureResultHookData {
    fixture: Fixture;
    layout?: FIXTURE_RESULT_LAYOUT;
    size?: FIXTURE_RESULT_SIZE;
    showDate?: boolean;
    showBackground?: boolean;
    isBigSize?: boolean;
}
export interface IUseMOMHookData {
    favoriteTeam: string;
    votes: Vote[];
    fixture: Fixture;
    voters_count: number;
    has_user_voted: boolean;
    average_grade: number;
    man_of_the_match: number;
    handleVote: (votes: PlayerRating[]) => void;
    loading: boolean;
    labels: {
        totalVotes: string;
        averageGrade: string;
        manOfTheMatch: string;
    };
}
export interface PlayerRating {
    key: number;
    value: number;
}
export interface IAdvertisment {
    id: number;
    position: string;
    alternative_content: string;
    content: string;
    slug: string;
    name: string;
    min_height: number | null;
    rotate: number | boolean;
}
export interface IUseLineupHookData {
    formations: Formation[];
    players: NPlayer[];
    onGetPreviusLineupClick: () => void;
    onSaveLineupClick: (selectedPlayers: NPlayer[], selectedFormation: Formation) => void;
    homeTeam: string;
    awayTeam: string;
    isLoggedIn: boolean;
    previusLienup: PreviusLineup | undefined;
}
export interface Formation {
    id: number;
    name: string;
    meta: Array<string[]>;
}
export interface Position {
    player: number;
    position: string;
}
export interface PreviusLineup {
    formation_id: number;
    positions: Position[];
}
export interface NPlayer extends Player {
    favFormationPosition?: string;
}
export interface PositionPlayerProps {
    player?: NPlayer | undefined | null;
    players: NPlayer[];
    position: string;
    maxPosition?: string;
    onSelectPlayer: (player: NPlayer) => void;
    onDeletePlayer: () => void;
}
export interface PositionPlayers {
    position: string;
    players: NPlayer[];
}
export interface ISeparatorOptions {
    thickness?: number;
    backgroundColorOnLightMode?: string;
    backgroundColorOnDarkMode?: string;
    isDarkMode?: boolean;
}
export {};
